@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import absolute_import
-
 from .client.pfs.pfs_pb2 import DIR, FILE, NONE, JSON, LINE, CSV, \
     Repo, Branch, BranchInfo, File, Block, Object, Tag, RepoInfo, \
     RepoAuthInfo, Commit, CommitRange, CommitInfo, FileInfo, ByteRange, \
     BlockRef, ObjectInfo, OverwriteIndex, PutFileRecord, PutFileRecords, \
-    ObjectIndex
+    ObjectIndex, CommitProvenance
+from .client.pfs.pfs_pb2 import \
+    STARTED as COMMIT_STATE_STARTED, \
+    READY as COMMIT_STATE_READY, \
+    FINISHED as COMMIT_STATE_FINISHED
 from .client.pps.pps_pb2 import JOB_FAILURE, JOB_KILLED, JOB_RUNNING, \
     JOB_STARTING, JOB_SUCCESS, FAILED, SUCCESS, SKIPPED, POD_SUCCESS, \
     POD_FAILED, POD_RUNNING, PIPELINE_FAILURE, PIPELINE_PAUSED, \
@@ -14,9 +16,15 @@ from .client.pps.pps_pb2 import JOB_FAILURE, JOB_KILLED, JOB_RUNNING, \
     Transform, Egress, Job, Service, PFSInput, CronInput, \
     GitInput, Input, JobInput, ParallelismSpec, HashtreeSpec, InputFile, \
     Datum, DatumInfo, Aggregate, ProcessStats, AggregateProcessStats, \
-    WorkerStatus, ResourceSpec, GPUSpec, EtcdJobInfo, JobInfo, Worker, \
-    Pipeline, PipelineInput, EtcdPipelineInfo, PipelineInfo, LogMessage, \
-    ChunkSpec, SchedulingSpec
+    WorkerStatus, ResourceSpec, GPUSpec, JobInfo, Worker, Pipeline, \
+    PipelineInput, PipelineInfo, LogMessage, ChunkSpec, SchedulingSpec, \
+    ListDatumStreamResponse, PipelineInfos
+from .client.pps.pps_pb2 import \
+    FAILED as DATUM_FAILED, \
+    SUCCESS as DATUM_SUCCESS, \
+    SKIPPED as DATUM_SKIPPED, \
+    STARTING as DATUM_STARTING, \
+    RECOVERED as DATUM_RECOVERED
 
 from .pfs_client import PfsClient
 from .pps_client import PpsClient
